@@ -13,13 +13,22 @@ Address and Postcode lookup service Postcoder http://www.postcoder.com/
 This module implements all the methods as defined by the SOAP 
 WSDL of Postcoder
 
+This module was funded by and developed for  Publicus Solutions LTD
+Visit: http://publicus-solutions.com
+
 Who uses it?
 ============
 Developers of web applications for service companies such as 
 property search websites, utility companies, telephone companies 
 and online retailers. It is ideal for online order and registration 
 forms, nearest look-up and map display.
+
+Where have we used this?
+========================
+This package is intended to be the platform for a module for our
+ERP systems. 
+Work is in progress for Tryton & Open ERP.
 """
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
